Skip to contents

This function gives the most distinguishing marker for a cluster

Usage

gimme_marker(markers, cluster_of_interest = 1)

Arguments

markers

A data frame or tibble containing marker genes with columns cluster, pct.1, and pct.2.

cluster_of_interest

The cluster number for which to find the most distinguishing marker. Default is 1.

Value

The most distinguishing marker for the specified cluster.