Skip to contents

This function calculates module scores for a Seurat object based on a list of gene sets.

Usage

score_signature(sc_obj, signature_list, seed = 1)

Arguments

sc_obj

A Seurat object.

signature_list

list. A list of gene sets, where each element is a character vector of gene names.

seed

An integer seed for reproducibility. Default is 1.

Value

A Seurat object with module scores added to the metadata.

Examples