Skip to contents

Performs data normalization, finds variable features, scales data, runs PCA, constructs graph-based neighbors and clusters, and generates UMAP embeddings.

Usage

seurat_standard_normalize_and_scale(
  seurat_obj,
  normalize_method = c("classic", "sctransform", "sctransform&regress"),
  conserve.memory = FALSE,
  cluster_resolution = 1,
  plot_dir = NULL,
  n_hv_gene = 10,
  verbose = TRUE
)

Arguments

seurat_obj

A Seurat object.

normalize_method

Character. Normalization method:

  • "classic" (LogNormalize + FindVariableFeatures + ScaleData)

  • "sctransform" (SCTransform).

  • "sctransform&regress" (SCTransform + regress out unwanted sources (currently only percent.mt)).

conserve.memory

Logical. Whether to conserve memory in SCTransform. Default: FALSE.

cluster_resolution

Numeric. Resolution for FindClusters. Default: 1.0.

plot_dir

Character. Directory to save variable feature plot. Default: NULL (i.e., not plot).

n_hv_gene

Integer. Number of top variable features to label. Default: 10.

verbose

Logical. Whether to print leo.log messages. Default: TRUE.

Value

A Seurat object after normalization, scaling, clustering, and UMAP embedding.